declare function isEmail(str: string): boolean;

declare function replaceAt(str: string, index?: number, replaceStr?: string): string;

declare function insertAt(str: string, index?: number, insertStr?: string): string;

declare function capitalize(str: string): string;

declare function camelCase(str: string): string;

declare function pascalCase(str: string): string;

declare function arrayDiff(arr1: unknown[], arr2: unknown[]): unknown[];

/**
 * It generates a sequence of numbers starting at the first argument,
 * progressing by the third argument, and stopping at the second argument.
 *
 * @example
 *
 * range(0, 5) // [0, 1, 2, 3, 4, 5]
 * range(10, 50, 10) // [10, 20, 30, 40, 50]
 */
declare function range(start: number | undefined, stop: number, step?: number): number[];

/**
 *  Array filter with `Async` callback function.
 *
 * @param arr unknown[]
 * @param cb - The callback funtion
 * @returns The filtered array
 */
declare function asyncFilter(arr: unknown[], cb: (value: unknown, index: number) => Promise<boolean>): Promise<unknown[]>;

type GroupKey = (a: unknown) => string | string;
declare function groupBy(arr: unknown[], key: GroupKey): {
    [x: string]: unknown;
};

/**
 * It moves an array element from one index position to another.
 *
 * Note: It mutates the array.
 *
 * @example
 *
 * move([1, 2, 3], 0, 2) //=> [2, 3, 1]
 */
declare function move<T>(arr: T[], from: number, to: number): T[];

/**
 * It returns percentage of value & total.
 * @param {number} value - The current value
 * @param {number} total - The total value
 * @returns {number}
 */
declare function percentage(value: number, total: number): number;

/**
 * It returns percentage of a number.
 * @param {number} percentage - The percentage to calculate
 * @param {number} num - The number to find percentage
 * @returns {number}
 */
declare function percentageOf(percentage: number, num: number): number;

declare function isNumber(value: unknown): boolean;

declare function isObj(obj: unknown): boolean;

declare function getInObj(obj: object, path: string): unknown;

declare function setInObj(obj: object, path: string, value: unknown): object;

declare function delInObj(obj: unknown, path: string): boolean;

declare function cloneObj(obj: any): any;

/**
 * Convert hexadecimal color values into RGB color values.
 * @param hex string
 * @returns number[]
 *
 * @example hexToRGB('#FF851B') => [ 255, 133, 27 ]
 */
declare function hexToRGB6(hex: string): number[];

declare function sleep(ms: number): Promise<void>;

export { arrayDiff, asyncFilter, camelCase, capitalize, cloneObj, delInObj, getInObj, groupBy, hexToRGB6 as hexToRGB, insertAt, isEmail, isNumber, isObj, move, pascalCase, percentage, percentageOf, range, replaceAt, setInObj, sleep };
